@@ -44,7 +44,7 @@ except ImportError:
     from urllib import urlencode
     from urllib2 import urlopen, Request, HTTPError
 
-__version__ = '1.2.34'
+__version__ = '1.2.35'
 __FILEABSDIRNAME__ = os.path.dirname(os.path.abspath(__file__))
 
 ini_files = (
@@ -402,9 +402,9 @@ class Agent:
         initial_data = True
         while True:
             if initial_data:
-                max_age = 10
+                max_span = 10
             else:
-                max_age = self.config.getint('agent', 'max_data_span')
+                max_span = self.config.getint('agent', 'max_data_span')
             loop_ts = time.time()
             if self.shutdown:
                 logging.info('%s:shutdown', threading.currentThread())
